@@ -335,7 +335,7 @@ class Pageview(aegis.database.Row):
 class HydraType(aegis.database.Row):
     table_name = 'hydra_type'
     id_column = 'hydra_type_id'
-    data_columns = ('hydra_type_name', 'hydra_type_desc', 'priority_ndx', 'next_run_sql', 'claimed_dttm', 'run_host')
+    data_columns = ('hydra_type_name', 'hydra_type_desc', 'priority_ndx', 'next_run_sql', 'claimed_dttm', 'run_host', 'run_env')
 
     @classmethod
     def get_name(cls, hydra_type_name):
@@ -356,15 +356,16 @@ class HydraType(aegis.database.Row):
         return db().execute(sql, status, self['hydra_type_id'])
 
     @classmethod
-    def get_runnable(cls, hydra_type_id):
+    def get_runnable(cls, hydra_type_id, env):
         sql = """SELECT hydra_type_id, hydra_type_name, next_run_sql
                    FROM hydra_type
                   WHERE next_run_dttm <= NOW()
                     AND status='live'
                     AND hydra_type_id=%s
+                    AND run_env=%s
                     AND claimed_dttm IS NULL
                     AND next_run_sql IS NOT NULL"""
-        return db().get(sql, hydra_type_id, cls=cls)
+        return db().get(sql, hydra_type_id, env, cls=cls)
 
     def schedule_next(self):
         sql = """
@@ -699,6 +700,17 @@ class Cache(aegis.database.Row):
         sql = "UPDATE cache SET cache_json=%s, cache_expiry=%s WHERE cache_key=%s"
         return db().execute(sql, cache_json, cache_expiry, cache_key)
 
+    @classmethod
+    def set_key(cls, cache_key, cache_json, cache_expiry):
+        cache_obj = cls.get_key(cache_key)
+        if cache_obj:
+            cls.update_key(cache_key, cache_json, cache_expiry)
+            cache_obj = cls.get_key(cache_key)
+        else:
+            cls.insert(cache_key, cache_json, cache_expiry)
+            cache_obj = cls.get_key(cache_key)
+        return cache_obj
+
     @staticmethod
     def del_key(cache_key):
         sql = "DELETE FROM cache WHERE cache_key=%s"
